==> moodle-3.3.1.zip: moodle/mod/wiki/lang/en/wiki.php <==
<?php
/**
 *
 * This file contains en_utf8 translation of Wiki module
 *
 * @author Jordi Piguillem
 * @author Kenneth Riba
 *
 * @license http://www.gnu.org/copyleft/gpl.html GNU Public License
 * @package mod_wiki
 */
$string['addcomment'] = 'Add comment';
$string['admin'] = 'Administration';
$string['adminmenu'] = 'Admin menu';
$string['attachmentattach'] = 'Add as attachment';
$string['attachmentimage'] = 'Add as image';
$string['attachmentlink'] = 'Add as link';
$string['attachments'] = 'Attachments';
$string['backcomments'] = 'Back to comments';
$string['backhistory'] = 'Back to history';
$string['backoldversion'] = 'Back to old version';
$string['backpage'] = 'Back to page';
$string['backtomapmenu'] = 'Back to map menu';
$string['changerate'] = 'Do you wish to change it?';
$string['cannotcomparenewerversion'] = 'A page version can only be compared with an older version.';
$string['cannoteditpage'] = 'You can not edit this page.';
$string['cannotmanagefiles'] = 'You don\'t have permission to manage the wiki files.';
$string['cannotviewfiles'] = 'You don\'t have permission to view the wiki files.';
$string['cannotviewpage'] = 'You can not view this page.';
$string['comparesel'] = 'Compare selected';
$string['comments'] = 'Comments';
$string['commentscount'] = 'Comments ({$a})';
$string['comparewith'] = 'Comparing version {$a->old} with version {$a->new}';
$string['contributions'] = 'Contributions';
$string['contributions_help'] = 'List of pages that you have edited.';
$string['createcomment'] = 'Creating comment';
$string['creating'] = 'Creating a wiki page';
$string['createpage'] = 'Create page';
$string['createddate'] = 'Created: {$a->date} by {$a->username}';
$string['creole'] = 'Creole';
$string['defaultformat'] = 'Default format';
$string['defaultformat_help'] = 'This setting determines the default format used when editing wiki pages.

* HTML - The HTML editor is available
* Creole - A common wiki markup language for which a small edit toolbar is available
* Nwiki - Mediawiki-like markup language used in the contributed Nwiki module';
$string['deleteallpages'] = 'Delete all wiki pages';
$string['deletecomment'] = 'Deleting comment';
$string['deletecommentcheck'] = 'Delete comment';
$string['deletecommentcheckfull'] = 'Are you sure you want to delete the comment?';
$string['deleteupload'] = 'Delete';
$string['deletedbegins'] = 'Deleted begins';
$string['deletedends'] = 'Deleted ends';
$string['deleteversions'] = 'Delete page versions';
$string['addedbegins'] = 'added begins';
$string['addedends'] = 'added ends';
$string['diff'] = 'Diff';
$string['diff_help'] = 'Selected versions of the page may be compared in order to find the differences.';
$string['edit'] = 'Edit';
$string['editcomment'] = 'Edit comment';
$string['editblocks'] = 'Turn edit blocks on';
$string['editfiles'] = 'Edit wiki files';
$string['editing'] = 'Editing wiki page';
$string['editingcomment'] = 'Editing comment';
$string['editingpage'] = 'Editing this page \'{$a}\'';
$string['editsection'] = 'edit';
$string['eventdiffviewed'] = 'Wiki diff viewed';
$string['eventhistoryviewed'] = 'Wiki history viewed';
$string['eventmapviewed'] = 'Wiki page map viewed';
$string['eventpagedeleted'] = 'Wiki page deleted';
$string['eventpagecreated'] = 'Wiki page created';
$string['eventpagelocksdeleted'] = 'Wiki page locks deleted';
$string['eventpageviewed'] = 'Wiki page viewed';
$string['eventpageupdated'] = 'Wiki page updated';
$string['eventpageversiondeleted'] = 'Wiki page version deleted';
$string['eventversionrestored'] = 'Wiki version restored';
$string['eventversionviewed'] = 'Wiki page version viewed';
$string['files'] = 'Files';
$string['filenotuploadederror'] = 'File \'{$a}\' could not be uploaded correctly.';
$string['filtername'] = 'Wiki auto-linking';
$string['firstpagetitle'] = 'First page name';
$string['firstpagetitle_help'] = 'Title of the first page of the wiki.';
$string['forceformat'] = 'Force format';
$string['forceformat_help'] = 'If the format is forced (checkbox ticked), there is no option to choose a format when editing a wiki page.';
$string['format'] = 'Format';
$string['format_help'] = '* HTML - The HTML editor is available
* Creole - A common wiki markup language for which a small edit toolbar is available
* Nwiki - Mediawiki-like markup language used in the contributed Nwiki module';
$string['formathtml'] = 'HTML format';
$string['formathtml_help'] = 'The HTML editor may be used for formatting content.

To create a new page, type the new page name enclosed in double square brackets, for example [[Page 2]].';
$string['formatcreole'] = 'Creole format';
$string['formatcreole_help'] = 'Creole is a common wiki markup language with an edit toolbar for inserting appropriate markup.

To create a new page, type the new page name enclosed in double square brackets, for example [[Page 2]].';
$string['formatcreole_link'] = 'mod/wiki/creole';
$string['formatnwiki'] = 'NWiki format';
$string['formatnwiki_help'] = 'Nwiki is the Mediawiki-like markup language used in the contributed Nwiki module.

To create a new page, type the new page name enclosed in double square brackets, for example [[Page 2]].';
$string['formatnwiki_link'] = 'mod/wiki/nwiki';
$string['history'] = 'History';
$string['history_help'] = 'The history lists links to previous versions of the page.';
$string['html'] = 'HTML';
$string['incorrectdeleteversions'] = "Page versions provided for deletion are incorrect.";
$string['incorrectpageid'] = 'Page ID is incorrect.';
$string['incorrectsubwikiid'] = 'Subwiki ID is incorrect.';
$string['incorrectwikiid'] = 'Wiki ID is incorrect.';
$string['insertcomment'] = 'Insert comment';
$string['insertimage'] = 'Insert an image...';
$string['insertimage_help'] = 'This drop-down list will insert an image to the wiki editor. If you need to add more images to the wiki, please use "Files" tab.';
$string['invalidlock'] = 'This page is already locked by another user.';
$string['invalidparameters'] = 'Invalid parameters have been given.';
$string['invalidsection'] = 'Invalid section.';
$string['invalidsesskey'] = 'Your session has most likely timed out. Please make a note of your edit then log in again.';
$string['individualpagedoesnotexist'] = 'Individual wiki page doesn\'t exist';
$string['javascriptdisabledlocks'] = 'Javascript is disabled on your browser and locks are not working. The changes you make may not be saved correctly.';
$string['lockingajaxtimeout'] = 'Edit page locking refresh time';
$string['lockingtimeout'] = 'Locking timeout';
$string['links'] = 'Links';
$string['listall'] = 'List all';
$string['listorphan'] = 'List orphan';
$string['map'] = 'Map';
$string['mapmenu'] = 'Map menu';
$string['migrationfinished'] = 'Migration finished successfully';
$string['migrationfinishednowikis'] = 'Migration finished, no wikis were migrated';
$string['missingpages'] = 'Pages without content';
$string['modified'] = 'Modified';
$string['modulename'] = 'Wiki';
$string['modulename_help'] = 'The wiki activity module enables participants to add and edit a collection of web pages. A wiki can be collaborative, with everyone being able to edit it, or individual, where everyone has their own wiki which only they can edit.

A history of previous versions of each page in the wiki is kept, listing the edits made by each participant.

Wikis have many uses, such as

* For group lecture notes or study guides
* For members of a faculty to plan a scheme of work or meeting agenda together
* For students to collaboratively author an online book, creating content on a topic set by their tutor
* For collaborative storytelling or poetry creation, where each participant writes a line or verse
* As a personal journal for examination notes or revision (using an individual wiki)';
$string['modulename_link'] = 'mod/wiki/view';
$string['modulenameplural'] = 'Wikis';
$string['navigation'] = 'Navigation';
$string['navigationfrom'] = 'This page comes from';
$string['navigationfrom_help'] = 'The wiki pages linking to this page';
$string['navigationto'] = 'This page goes to';
$string['navigationto_help'] = 'Links to other pages';
$string['newpage'] = 'New';
$string['newpagehdr'] = 'New page';
$string['newpagetitle'] = 'New page title';
$string['noattachments'] = '<strong>No files attached</strong>';
$string['nocontent'] = 'There is no content for this page';
$string['nocontribs'] = 'You have no contributions in this wiki';
$string['nocomments'] = 'There are no comments';
$string['nocreatepermission'] = 'Create page permission needed';
$string['noeditcommentpermission'] = 'Edit comment permission needed';
$string['noeditpermission'] = 'Edit page permission needed';
$string['nofrompages'] = 'There are no links to this page';
$string['nohistory'] = 'There is no history for this page';
$string['nomanagecommentpermission'] = 'Manage comments permission needed';
$string['nomanagewikipermission'] = 'Manage wiki permission needed';
$string['noorphanedpages'] = 'There are no orphaned pages';
$string['nooverridelockpermission'] = 'Override lock permission needed';
$string['norated']='This page has not been rated yet, be the first!';
$string['norating'] = 'No rating';
$string['nosearchresults'] = 'No results';
$string['noteditblocks'] = 'Turn edit blocks off';
$string['notingroup'] = 'Not in group';
$string['notopages'] = 'This page does not link to other pages';
$string['notmigrated'] = 'This wiki has not been migrated yet. Please contact your administrator.';
$string['noupdatedpages'] = 'There are no updated pages';
$string['noviewcommentpermission'] = 'View comments permission needed';
$string['noviewpagepermission'] = 'View page permission needed';
$string['nwiki'] = 'NWiki';
$string['oldversion'] = 'Old version';
$string['orphaned'] = 'Orphaned pages';
$string['orphaned_help'] = 'List of pages that are not linked from other page.';
$string['overridelocks'] = 'Override locks';
$string['overridinglocks'] = 'Overriding locks...';
$string['page-mod-wiki-x'] = 'Any wiki module page';
$string['page-mod-wiki-view'] = 'Wiki module main page';
$string['page-mod-wiki-comments'] = 'Wiki module comments page';
$string['page-mod-wiki-history'] = 'Wiki history page';
$string['page-mod-wiki-map'] = 'Wiki map page';
$string['pageexists'] = 'This page already exists.';
$string['pageindex'] = 'Page Index';
$string['pageindex_help'] = 'This wiki\'s page tree';
$string['pageislocked'] = 'Someone is editing this page right now. Try to edit it in a few minutes.';
$string['pagelist'] = 'Page list';
$string['pagelist_help'] = 'Page list categorized by alphabetical order';
$string['pagename'] = 'Page name';
$string['peerreview'] = 'Peer review';
$string['pluginadministration'] = 'Wiki administration';
$string['pluginname'] = 'Wiki';
$string['prettyprint'] = 'Printer-friendly version';
$string['print'] = 'Print';
$string['previewwarning'] = 'This is a preview. Changes have not been saved yet.';
$string['rated']='You rated this page as a {$a}';
$string['rating']='Rating';
$string['ratingmode'] = 'Rating mode';
$string['reparsetimeout'] = 'Reparsing default timeout';
$string['repeatedsection'] = 'Wiki error: Section name cannot be repeated \'{$a}\'';
$string['restore'] = 'Restore';
$string['removeallwikitags'] = 'Remove all wiki tags';
$string['removepages'] = 'Remove pages';
$string['restoreconfirm'] = 'Are you sure you want to restore version #{$a}?';
$string['restoreerror'] = 'Version #{$a} could not be restored';
$string['restorethis'] = 'Restore this version';
$string['restoreversion'] = 'Restore old version';
$string['restoring'] = 'Restoring version #{$a}';
$string['return'] = 'Go back';
$string['save'] = 'Save';
$string['saving'] = 'Saving wiki page';
$string['savingerror'] = 'Saving error';
$string['search:activity'] = 'Wiki - activity information';
$string['search:collaborative_page'] = 'Wiki - collaborative pages';
$string['searchcontent'] = 'Search in page content';
$string['searchresult'] = 'Search results:';
$string['searchterms'] = 'Search terms';
$string['searchwikis'] = 'Search wikis';
$string['special'] = 'Special';
$string['tableofcontents'] = 'Table of contents';
$string['tagarea_wiki_pages'] = 'Wiki pages';
$string['tagsdeleted'] = 'Wiki tags have been deleted';
$string['tagtitle'] = 'See the "{$a}" tag';
$string['teacherrating'] = 'Teacher rating';
$string['timesrating']='This page has been rated  {$a->c} times with an average of: {$a->s}';
$string['updatedpages'] = "Updated pages";
$string['updatedpages_help'] = "Recently updated wiki pages";
$string['updatedwikipages'] = "Updated wiki pages";
$string['upload'] = "Upload & Delete";
$string['uploadname'] = "Filename";
$string['uploadactions'] = "Actions";
$string['uploadtitle'] = 'Attach files';
$string['uploadfiletitle'] = 'Attachments';
$string['versionerror'] = 'Version ID does not exist';
$string['versionnum'] = 'Version #{$a}';
$string['version'] = 'Version';
$string['view'] = 'View';
$string['viewallhistory'] = 'View all history';
$string['viewperpage'] = 'Show {$a} versions per page';
$string['viewversion'] = 'Viewing page version #{$a}';
$string['viewcurrent'] = 'Current version';
$string['wiki'] = 'Wiki';
$string['wikiattachments'] = 'Wiki attachments';
$string['wikiboldtext'] = 'Bold text';
$string['wikiexternalurl'] = 'External URL';
$string['wikifiletable'] = 'Uploaded file list';
$string['wikifiles'] = 'Wiki files';
$string['wikiheader'] = 'Level {$a} Header';
$string['wikihr'] = 'Horizontal rule';
$string['wikiimage'] = 'Image';
$string['wikiinternalurl'] = 'Internal link';
$string['wikiintro'] = 'Description';
$string['wikiitalictext'] = 'Italic text';
$string['wikilockingsettings'] = 'Locking and reparsing timeouts';
$string['wikimode'] = 'Wiki mode';
$string['wikimode_help'] = 'The wiki mode determines whether everyone can edit the wiki - a collaborative wiki - or whether everyone has their own wiki which only they can edit - an individual wiki.';
$string['wikimodecollaborative'] = 'Collaborative wiki';
$string['wikimodeindividual'] = 'Individual wiki';
$string['wikiname'] = 'Wiki name';
$string['wikinowikitext'] = 'No wiki text';
$string['wikiorderedlist'] = 'Ordered list';
$string['wikisettings'] = 'Wiki settings';
$string['wikiunorderedlist'] = 'Unordered list';
$string['wiki:addinstance'] = 'Add a new wiki';
$string['wiki:createpage'] = 'Create new wiki pages';
$string['wiki:editcomment'] = 'Add comments to pages';
$string['wiki:editpage'] = 'Save wiki pages';
$string['wiki:managecomment'] = 'Manage wiki comments';
$string['wiki:managewiki'] = 'Manage wiki settings';
$string['wiki:managefiles'] = 'Manage wiki files';
$string['wiki:overridelock'] = 'Override wiki locks';
$string['wiki:viewcomment'] = 'View page comments';
$string['wiki:viewpage'] = 'View wiki pages';
$string['wikipages'] = 'Wiki pages';
$string['wrongversionlock'] = 'Another user has edited this page while you were editing and your content is obsolete.';
$string['wrongversionsave'] = 'Another user has created a version while you were editing and you have overwritten his changes, check the page history.';

==> moodle-3.3.4.zip: moodle/mod/wiki/lang/en/wiki.php <==
<?php
/**
 *
 * This file contains en_utf8 translation of Wiki module
 *
 * @author Jordi Piguillem
 * @author Kenneth Riba
 *
 * @license http://www.gnu.org/copyleft/gpl.html GNU Public License
 * @package mod_wiki
 */
$string['addcomment'] = 'Add comment';
$string['admin'] = 'Administration';
$string['adminmenu'] = 'Admin menu';
$string['attachmentattach'] = 'Add as attachment';
$string['attachmentimage'] = 'Add as image';
$string['attachmentlink'] = 'Add as link';
$string['attachments'] = 'Attachments';
$string['backcomments'] = 'Back to comments';
$string['backhistory'] = 'Back to history';
$string['backoldversion'] = 'Back to old version';
$string['backpage'] = 'Back to page';
$string['backtomapmenu'] = 'Back to map menu';
$string['changerate'] = 'Do you wish to change it?';
$string['cannotcomparenewerversion'] = 'A page version can only be compared with an older version.';
$string['cannoteditpage'] = 'You can not edit this page.';
$string['cannotmanagefiles'] = 'You don\'t have permission to manage the wiki files.';
$string['cannotviewfiles'] = 'You don\'t have permission to view the wiki files.';
$string['cannotviewpage'] = 'You can not view this page.';
$string['comparesel'] = 'Compare selected';
$string['comments'] = 'Comments';
$string['commentscount'] = 'Comments ({$a})';
$string['comparewith'] = 'Comparing version {$a->old} with version {$a->new}';
$string['contributions'] = 'Contributions';
$string['contributions_help'] = 'List of pages that you have edited.';
$string['createcomment'] = 'Creating comment';
$string['creating'] = 'Creating a wiki page';
$string['createpage'] = 'Create page';
$string['createddate'] = 'Created: {$a->date} by {$a->username}';
$string['creole'] = 'Creole';
$string['defaultformat'] = 'Default format';
$string['defaultformat_help'] = 'This setting determines the default format used when editing wiki pages.

* HTML - The HTML editor is available
* Creole - A common wiki markup language for which a small edit toolbar is available
* Nwiki - Mediawiki-like markup language used in the contributed Nwiki module';
$string['deleteallpages'] = 'Delete all wiki pages';
$string['deletecomment'] = 'Deleting comment';
$string['deletecommentcheck'] = 'Delete comment';
$string['deletecommentcheckfull'] = 'Are you sure you want to delete the comment?';
$string['deleteupload'] = 'Delete';
$string['deletedbegins'] = 'Deleted begins';
$string['deletedends'] = 'Deleted ends';
$string['deleteversions'] = 'Delete page versions';
$string['addedbegins'] = 'added begins';
$string['addedends'] = 'added ends';
$string['diff'] = 'Diff';
$string['diff_help'] = 'Selected versions of the page may be compared in order to find the differences.';
$string['edit'] = 'Edit';
$string['editcomment'] = 'Edit comment';
$string['editblocks'] = 'Turn edit blocks on';
$string['editfiles'] = 'Edit wiki files';
$string['editing'] = 'Editing wiki page';
$string['editingcomment'] = 'Editing comment';
$string['editingpage'] = 'Editing this page \'{$a}\'';
$string['editsection'] = 'edit';
$string['eventdiffviewed'] = 'Wiki diff viewed';
$string['eventhistoryviewed'] = 'Wiki history viewed';
$string['eventmapviewed'] = 'Wiki page map viewed';
$string['eventpagedeleted'] = 'Wiki page deleted';
$string['eventpagecreated'] = 'Wiki page created';
$string['eventpagelocksdeleted'] = 'Wiki page locks deleted';
$string['eventpageviewed'] = 'Wiki page viewed';
$string['eventpageupdated'] = 'Wiki page updated';
$string['eventpageversiondeleted'] = 'Wiki page version deleted';
$string['eventversionrestored'] = 'Wiki version restored';
$string['eventversionviewed'] = 'Wiki page version viewed';
$string['files'] = 'Files';
$string['filenotuploadederror'] = 'File \'{$a}\' could not be uploaded correctly.';
$string['filtername'] = 'Wiki auto-linking';
$string['firstpagetitle'] = 'First page name';
$string['firstpagetitle_help'] = 'Title of the first page of the wiki. Once the wiki is created, the title can no longer be changed.';
$string['forceformat'] = 'Force format';
$string['forceformat_help'] = 'If the format is forced (checkbox ticked), there is no option to choose a format when editing a wiki page.';
$string['format'] = 'Format';
$string['format_help'] = '* HTML - The HTML editor is available
* Creole - A common wiki markup language for which a small edit toolbar is available
* Nwiki - Mediawiki-like markup language used in the contributed Nwiki module';
$string['formathtml'] = 'HTML format';
$string['formathtml_help'] = 'The HTML editor may be used for formatting content.

To create a new page, type the new page name enclosed in double square brackets, for example [[Page 2]].';
$string['formatcreole'] = 'Creole format';
$string['formatcreole_help'] = 'Creole is a common wiki markup language with an edit toolbar for inserting appropriate markup.

To create a new page, type the new page name enclosed in double square brackets, for example [[Page 2]].';
$string['formatcreole_link'] = 'mod/wiki/creole';
$string['formatnwiki'] = 'NWiki format';
$string['formatnwiki_help'] = 'Nwiki is the Mediawiki-like markup language used in the contributed Nwiki module.

To create a new page, type the new page name enclosed in double square brackets, for example [[Page 2]].';
$string['formatnwiki_link'] = 'mod/wiki/nwiki';
$string['history'] = 'History';
$string['history_help'] = 'The history lists links to previous versions of the page.';
$string['html'] = 'HTML';
$string['incorrectdeleteversions'] = "Page versions provided for deletion are incorrect.";
$string['incorrectpageid'] = 'Page ID is incorrect.';
$string['incorrectsubwikiid'] = 'Subwiki ID is incorrect.';
$string['incorrectwikiid'] = 'Wiki ID is incorrect.';
$string['insertcomment'] = 'Insert comment';
$string['insertimage'] = 'Insert an image...';
$string['insertimage_help'] = 'This drop-down list will insert an image to the wiki editor. If you need to add more images to the wiki, please use "Files" tab.';
$string['invalidlock'] = 'This page is already locked by another user.';
$string['invalidparameters'] = 'Invalid parameters have been given.';
$string['invalidsection'] = 'Invalid section.';
$string['invalidsesskey'] = 'Your session has most likely timed out. Please make a note of your edit then log in again.';
$string['individualpagedoesnotexist'] = 'Individual wiki page doesn\'t exist';
$string['javascriptdisabledlocks'] = 'Javascript is disabled on your browser and locks are not working. The changes you make may not be saved correctly.';
$string['lockingajaxtimeout'] = 'Edit page locking refresh time';
$string['lockingtimeout'] = 'Locking timeout';
$string['links'] = 'Links';
$string['listall'] = 'List all';
$string['listorphan'] = 'List orphan';
$string['map'] = 'Map';
$string['mapmenu'] = 'Map menu';
$string['migrationfinished'] = 'Migration finished successfully';
$string['migrationfinishednowikis'] = 'Migration finished, no wikis were migrated';
$string['missingpages'] = 'Pages without content';
$string['modified'] = 'Modified';
$string['modulename'] = 'Wiki';
$string['modulename_help'] = 'The wiki activity module enables participants to add and edit a collection of web pages. A wiki can be collaborative, with everyone being able to edit it, or individual, where everyone has their own wiki which only they can edit.

A history of previous versions of each page in the wiki is kept, listing the edits made by each participant.

Wikis have many uses, such as

* For group lecture notes or study guides
* For members of a faculty to plan a scheme of work or meeting agenda together
* For students to collaboratively author an online book, creating content on a topic set by their tutor
* For collaborative storytelling or poetry creation, where each participant writes a line or verse
* As a personal journal for examination notes or revision (using an individual wiki)';
$string['modulename_link'] = 'mod/wiki/view';
$string['modulenameplural'] = 'Wikis';
$string['navigation'] = 'Navigation';
$string['navigationfrom'] = 'This page comes from';
$string['navigationfrom_help'] = 'The wiki pages linking to this page';
$string['navigationto'] = 'This page goes to';
$string['navigationto_help'] = 'Links to other pages';
$string['newpage'] = 'New';
$string['newpagehdr'] = 'New page';
$string['newpagetitle'] = 'New page title';
$string['noattachments'] = '<strong>No files attached</strong>';
$string['nocontent'] = 'There is no content for this page';
$string['nocontribs'] = 'You have no contributions in this wiki';
$string['nocomments'] = 'There are no comments';
$string['nocreatepermission'] = 'Create page permission needed';
$string['noeditcommentpermission'] = 'Edit comment permission needed';
$string['noeditpermission'] = 'Edit page permission needed';
$string['nofrompages'] = 'There are no links to this page';
$string['nohistory'] = 'There is no history for this page';
$string['nomanagecommentpermission'] = 'Manage comments permission needed';
$string['nomanagewikipermission'] = 'Manage wiki permission needed';
$string['noorphanedpages'] = 'There are no orphaned pages';
$string['nooverridelockpermission'] = 'Override lock permission needed';
$string['norated']='This page has not been rated yet, be the first!';
$string['norating'] = 'No rating';
$string['nosearchresults'] = 'No results';
$string['noteditblocks'] = 'Turn edit blocks off';
$string['notingroup'] = 'Not in group';
$string['notopages'] = 'This page does not link to other pages';
$string['notmigrated'] = 'This wiki has not been migrated yet. Please contact your administrator.';
$string['noupdatedpages'] = 'There are no updated pages';
$string['noviewcommentpermission'] = 'View comments permission needed';
$string['noviewpagepermission'] = 'View page permission needed';
$string['nwiki'] = 'NWiki';
$string['oldversion'] = 'Old version';
$string['orphaned'] = 'Orphaned pages';
$string['orphaned_help'] = 'List of pages that are not linked from other page.';
$string['overridelocks'] = 'Override locks';
$string['overridinglocks'] = 'Overriding locks...';
$string['page-mod-wiki-x'] = 'Any wiki module page';
$string['page-mod-wiki-view'] = 'Wiki module main page';
$string['page-mod-wiki-comments'] = 'Wiki module comments page';
$string['page-mod-wiki-history'] = 'Wiki history page';
$string['page-mod-wiki-map'] = 'Wiki map page';
$string['pageexists'] = 'This page already exists.';
$string['pageindex'] = 'Page Index';
$string['pageindex_help'] = 'This wiki\'s page tree';
$string['pageislocked'] = 'Someone is editing this page right now. Try to edit it in a few minutes.';
$string['pagelist'] = 'Page list';
$string['pagelist_help'] = 'Page list categorized by alphabetical order';
$string['pagename'] = 'Page name';
$string['peerreview'] = 'Peer review';
$string['pluginadministration'] = 'Wiki administration';
$string['pluginname'] = 'Wiki';
$string['prettyprint'] = 'Printer-friendly version';
$string['print'] = 'Print';
$string['previewwarning'] = 'This is a preview. Changes have not been saved yet.';
$string['rated']='You rated this page as a {$a}';
$string['rating']='Rating';
$string['ratingmode'] = 'Rating mode';
$string['reparsetimeout'] = 'Reparsing default timeout';
$string['repeatedsection'] = 'Wiki error: Section name cannot be repeated \'{$a}\'';
$string['restore'] = 'Restore';
$string['removeallwikitags'] = 'Remove all wiki tags';
$string['removepages'] = 'Remove pages';
$string['restoreconfirm'] = 'Are you sure you want to restore version #{$a}?';
$string['restoreerror'] = 'Version #{$a} could not be restored';
$string['restorethis'] = 'Restore this version';
$string['restoreversion'] = 'Restore old version';
$string['restoring'] = 'Restoring version #{$a}';
$string['return'] = 'Go back';
$string['save'] = 'Save';
$string['saving'] = 'Saving wiki page';
$string['savingerror'] = 'Saving error';
$string['search:activity'] = 'Wiki - activity information';
$string['search:collaborative_page'] = 'Wiki - collaborative pages';
$string['searchcontent'] = 'Search in page content';
$string['searchresult'] = 'Search results:';
$string['searchterms'] = 'Search terms';
$string['searchwikis'] = 'Search wikis';
$string['special'] = 'Special';
$string['tableofcontents'] = 'Table of contents';
$string['tagarea_wiki_pages'] = 'Wiki pages';
$string['tagsdeleted'] = 'Wiki tags have been deleted';
$string['tagtitle'] = 'See the "{$a}" tag';
$string['teacherrating'] = 'Teacher rating';
$string['timesrating']='This page has been rated  {$a->c} times with an average of: {$a->s}';
$string['updatedpages'] = "Updated pages";
$string['updatedpages_help'] = "Recently updated wiki pages";
$string['updatedwikipages'] = "Updated wiki pages";
$string['upload'] = "Upload & Delete";
$string['uploadname'] = "Filename";
$string['uploadactions'] = "Actions";
$string['uploadtitle'] = 'Attach files';
$string['uploadfiletitle'] = 'Attachments';
$string['versionerror'] = 'Version ID does not exist';
$string['versionnum'] = 'Version #{$a}';
$string['version'] = 'Version';
$string['view'] = 'View';
$string['viewallhistory'] = 'View all history';
$string['viewperpage'] = 'Show {$a} versions per page';
$string['viewversion'] = 'Viewing page version #{$a}';
$string['viewcurrent'] = 'Current version';
$string['wiki'] = 'Wiki';
$string['wikiattachments'] = 'Wiki attachments';
$string['wikiboldtext'] = 'Bold text';
$string['wikiexternalurl'] = 'External URL';
$string['wikifiletable'] = 'Uploaded file list';
$string['wikifiles'] = 'Wiki files';
$string['wikiheader'] = 'Level {$a} Header';
$string['wikihr'] = 'Horizontal rule';
$string['wikiimage'] = 'Image';
$string['wikiinternalurl'] = 'Internal link';
$string['wikiintro'] = 'Description';
$string['wikiitalictext'] = 'Italic text';
$string['wikilockingsettings'] = 'Locking and reparsing timeouts';
$string['wikimode'] = 'Wiki mode';
$string['wikimode_help'] = 'The wiki mode determines whether everyone can edit the wiki - a collaborative wiki - or whether everyone has their own wiki which only they can edit - an individual wiki.';
$string['wikimodecollaborative'] = 'Collaborative wiki';
$string['wikimodeindividual'] = 'Individual wiki';
$string['wikiname'] = 'Wiki name';
$string['wikinowikitext'] = 'No wiki text';
$string['wikiorderedlist'] = 'Ordered list';
$string['wikisettings'] = 'Wiki settings';
$string['wikiunorderedlist'] = 'Unordered list';
$string['wiki:addinstance'] = 'Add a new wiki';
$string['wiki:createpage'] = 'Create new wiki pages';
$string['wiki:editcomment'] = 'Add comments to pages';
$string['wiki:editpage'] = 'Save wiki pages';
$string['wiki:managecomment'] = 'Manage wiki comments';
$string['wiki:managewiki'] = 'Manage wiki settings';
$string['wiki:managefiles'] = 'Manage wiki files';
$string['wiki:overridelock'] = 'Override wiki locks';
$string['wiki:viewcomment'] = 'View page comments';
$string['wiki:viewpage'] = 'View wiki pages';
$string['wikipages'] = 'Wiki pages';
$string['wrongversionlock'] = 'Another user has edited this page while you were editing and your content is obsolete.';
$string['wrongversionsave'] = 'Another user has created a version while you were editing and you have overwritten his changes, check the page history.';
